/* 
   Runtime stack backtrace facilities
   Copyright (C) Elrond                            2001

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


/* Samba specific stuff */
#include "includes.h"
#include "libsamba.h"

#define MSG(x) DEBUG(0, x)
#define MSGADD(x) DEBUGADD(0, x)


/* The rest of the file is mostly generic */


#ifdef HAVE_GLIBC_BACKTRACE

#include <execinfo.h>
#include <stdio.h>

int generate_backtrace(void)
{
  void *stack[100];
  int size, i;
  char **syms;

  size = backtrace(stack, 100);
  if (size == 0) {
    MSG(("backtrace returned 0 entries\n"));
    return 0;
  }
  syms = backtrace_symbols(stack, size);
  if (!syms) {
    MSG(("backtrace_symbols returned NULL\n"));
    return 0;
  }
  MSG(("Stack backtrace:\n"));
  for(i = 0; i < size; i++) {
    MSGADD(("  %s\n", syms[i]));
  }
  return size;
}

#else

 int generate_backtrace(void)
{
  /* not supported, simply do nothing */
  return 0;
}

#endif
