/* 
 *  Unix SMB/Netbios implementation.
 *  Version 1.9.
 *  RPC Pipe client / server routines
 *  Copyright (C) Andrew Tridgell              1992-1999,
 *  Copyright (C) Luke Kenneth Casson Leighton 1996-1999,
 *  Copyright (C) Elrond <elrond@samba-tng.org>     2001,
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "includes.h"
#include "libsamba.h"
#include "rpc_parse.h"
#include "rpc_client.h"
#include "nterr.h"

/****************************************************************************
do a BRS Query 
****************************************************************************/
BOOL brs_query_info(const char *srv_name, uint32 switch_value, void *id)
{
	prs_struct rbuf;
	prs_struct buf; 
	BRS_Q_QUERY_INFO q_o;
	BOOL valid_info = False;

	struct cli_connection *con = NULL;

	if (!cli_connection_init(srv_name, PIPE_BROWSER, &con))
	{
		return False;
	}

	if (id == NULL) return False;

	prs_init(&buf , 0, 4, False);
	prs_init(&rbuf, 0, 4, True );

	DEBUG(4,("BRS Query Info\n"));

	/* store the parameters */
	make_brs_q_query_info(&q_o, srv_name, switch_value);

	/* turn parameters into data stream */
	if (brs_io_q_query_info("", &q_o, &buf, 0) &&
	    rpc_con_pipe_req(con, BRS_QUERY_INFO, &buf, &rbuf))
	{
		BRS_R_QUERY_INFO r_o;
		BOOL p;

		r_o.info.id = id;

		brs_io_r_query_info("", &r_o, &rbuf, 0);
		p = rbuf.offset != 0;

		if (p && r_o.status != 0)
		{
			/* report error code */
			DEBUG(0,("BRS_R_QUERY_INFO: %s\n", get_nt_error_msg(r_o.status)));
			p = False;
		}

		if (p)
		{
			valid_info = True;
		}
	}

	prs_free_data(&rbuf);
	prs_free_data(&buf );

	cli_connection_unlink(con);

	return valid_info;
}

/****************************************************************************
****************************************************************************/
uint32 brs_query_stats(const UNISTR2 *uni_srv_name, BRS_STATS *stats)
{
	prs_struct rbuf;
	prs_struct buf; 
	BRS_Q_QUERY_STATS q_o;
	BRS_R_QUERY_STATS q_r;
	struct cli_connection *con = NULL;
	fstring srv_name;
	uint32 status = NT_STATUS_UNSUCCESSFUL;

	unistr2_to_ascii(srv_name, uni_srv_name, sizeof(srv_name) - 1);

	if (!cli_connection_init(srv_name, PIPE_BROWSER, &con))
	{
		return NT_STATUS_UNSUCCESSFUL;
	}

	prs_init(&buf , 0, 4, False);
	prs_init(&rbuf, 0, 4, True );

	/* store the parameters */
	copy_unistr2(&q_o.uni_srv_name, uni_srv_name);

	/* turn parameters into data stream */
	if (brs_io_q_query_stats("", &q_o, &buf, 0)
	    && rpc_con_pipe_req(con, BRS_QUERY_STATS, &buf, &rbuf)
	    && brs_io_r_query_stats("", &q_r, &rbuf, 0) )
	{
		status = q_r.status;
		*stats = q_r.stats;
	}

	prs_free_data(&rbuf);
	prs_free_data(&buf );

	cli_connection_unlink(con);

	return status;
}
