/* 
   Unix SMB/Netbios implementation.
   Version 1.9.
   NT Domain Authentication SMB / MSRPC client
   Copyright (C) Andrew Tridgell 1994-1999
   Copyright (C) Luke Kenneth Casson Leighton 1996-1999
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "includes.h"
#include "libsamba.h"
#include "rpc_brs.h"
#include "rpc_client.h"
#include "rpcclient.h"
#include "nterr.h"

extern FILE* out_hnd;

/****************************************************************************
Browser get info query
****************************************************************************/
void cmd_brs_query_info(struct client_info *info, int argc, char *argv[])
{
	fstring dest_brs;
	BRS_INFO_100 ctr;
	uint32 info_level = 100;

	BOOL res = True;

	ZERO_STRUCT(ctr);

	fstrcpy(dest_brs, "\\\\");
	fstrcat(dest_brs, info->dest_host);
	strupper(dest_brs);

	if (argc > 1)
	{
		info_level = (uint32)strtol(argv[1], (char**)NULL, 10);
	}

	DEBUG(4,("cmd_brs_query_info: server:%s info level: %d\n",
				dest_brs, info_level));

	/* send info level: receive requested info.  hopefully. */
	res = res ? brs_query_info( dest_brs, info_level, &ctr) : False;

	if (res)
	{
		DEBUG(5,("cmd_brs_query_info: query succeeded\n"));

#if 0
		display_brs_info_100(out_hnd, ACTION_HEADER   , &ctr);
		display_brs_info_100(out_hnd, ACTION_ENUMERATE, &ctr);
		display_brs_info_100(out_hnd, ACTION_FOOTER   , &ctr);
#endif

	}
	else
	{
		report(out_hnd, "cmd_brs_query_info: query failed\n");
	}
}

/****************************************************************************
****************************************************************************/
static void display_brs_stats(FILE *out, const BRS_STATS *stats)
{
	unsigned int i;

	display_nttime(out, "Browser stats started at: ",
		       &stats->start_time);
	for(i = 0; i < (sizeof(stats->stat_data) / sizeof(stats->stat_data[0])); i++)
	{
		report(out, "\t stat_data[%d]: %d (0x%x)\n", i,
		       stats->stat_data[i], stats->stat_data[i]);
	}
}


uint32 cmd_brs_query_stats(struct client_info *info, int argc, char *argv[])
{
	fstring dest_brs;
	UNISTR2 uni_srv_name;
	uint32 status = 0x0;
	BRS_STATS brs_stats;

	fstrcpy(dest_brs, "\\\\");
	fstrcat(dest_brs, info->dest_host);
	strupper(dest_brs);
	unistr2_assign_ascii(&uni_srv_name, dest_brs, strlen(dest_brs) + 1);

	status = brs_query_stats(&uni_srv_name, &brs_stats);

	if (status == 0x0)
		display_brs_stats(out_hnd, &brs_stats);

	return status;
}
