/* 
   Unix SMB/Netbios implementation.
   Version 1.9.
   Samba utility functions
   Copyright (C) Andrew Tridgell 1992-1999
   Copyright (C) Luke Kenneth Casson Leighton 1996 - 1999
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "includes.h"
#include "libsamba.h"
#include "rpcclient.h"


static const char *eventtype_str(uint16 eventtype)
{
	switch (eventtype)
	{
		case EVENTLOG_OK:
			return "Normal";

		case EVENTLOG_ERROR:
			return "Error";

		case EVENTLOG_WARNING:
			return "Warning";

		case EVENTLOG_INFORMATION:
			return "Information";

		case EVENTLOG_AUDIT_OK:
			return "Audit Normal";

		case EVENTLOG_AUDIT_ERROR:
			return "Audit Error";
	}

	return "Unknown";
}


/****************************************************************************
 display structure
 ****************************************************************************/
void display_eventlog_eventrecord(FILE *out_hnd, enum action_type action, EVENTLOGRECORD *const ev)
{
	switch (action)
	{
		case ACTION_HEADER:
		{
			report(out_hnd, "\tevent log records\n");
			report(out_hnd, "\t-----------------\n");
			break;
		}
		case ACTION_ENUMERATE:
		{
			pstring temp;
			report(out_hnd, "\t\trecord n.:\t%d\n", ev->recordnumber);

			report(out_hnd, "\t\teventtype\teventnumber\tcategory\tsource\n");

			report(out_hnd, "\t\t%-16s",
			       eventtype_str(ev->eventtype));

			report(out_hnd, "%d\t\t", ev->eventnumber&0x0000FFFF);
			report(out_hnd, "%d\t\t", ev->category);
			unistr_to_ascii(temp, ev->sourcename.buffer, sizeof(temp)-1);
			report(out_hnd, "%s\n", temp);

			report(out_hnd, "\t\tcreationtime:\t%s\n", http_timestring(ev->creationtime));
			report(out_hnd, "\t\twritetime:\t%s\n", http_timestring(ev->writetime));

			unistr_to_ascii(temp, ev->computername.buffer, sizeof(temp)-1);
			report(out_hnd, "\t\tcomputer:\t%s\n", temp);

			if (ev->sid_length)
			{
				sid_to_string(temp, &ev->sid);
				report(out_hnd, "\t\tSID:\t\t%s\n", temp);
			}

			if (ev->num_of_strings && ev->strings)
			{
				uint32 i;
				report(out_hnd, "\t\tStrings:\n");
				for (i = 0; i < ev->num_of_strings; i++)
				{
					unistr_to_ascii(temp,
							ev->strings[i]->buffer,
							sizeof(temp)-1);
					report(out_hnd, "\t\t\t%s\n", temp);
					safe_free(ev->strings[i]);
				}
				safe_free(ev->strings);
				ev->strings = NULL;
			}

			report(out_hnd, "\n");
			break;
		}
		case ACTION_FOOTER:
		{
			report(out_hnd, "\n");
			break;
		}
	}
}
